==> ejc-guarantee-impl-3.0.0-20240306.080439-60-sources.jar: com/ejianc/business/guarantee/contract/bean/ContractBidEntity.java <==
package com.ejianc.business.guarantee.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标担保
 *
 * @author generator
 */
@TableName("ejc_guarantee_contract_bid")
public class ContractBidEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; // 单据编码
    @TableField(value = "org_id")
    private Long orgId; // 组织id
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "create_user_name")
    private String createUserName; // 编制人
    @TableField(value = "operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value = "operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value = "update_user_name")
    private String updateUserName; // 修改者
    @TableField(value = "remark")
    private String remark; // 备注
    @TableField(value = "contract_id")
    private Long contractId; // 合同评审id
    @TableField(value = "contract_name")
    private String contractName; // 合同名称
    @TableField(value = "project_id")
    private String projectId; // 项目
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "self_code")
    private String selfCode; // 自定义编号
    @TableField(value = "apply_area")
    private String applyArea; // 申请地区
    @TableField(value = "apply_area_name")
    private String applyAreaName; // 申请地区名称
    @TableField(value = "employee_id")
    private Long employeeId; // 委托保证人
    @TableField(value = "employee_name")
    private String employeeName; // 委托保证人名称
    @TableField(value = "applicant")
    private Long applicant; // 申请人
    @TableField(value = "applicant_name")
    private String applicantName; // 申请名称
    @TableField(value = "project_type")
    private Long projectType; // 项目类型
    @TableField(value = "project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value = "base_tax_mny")
    private BigDecimal baseTaxMny; // 初始担保金额（含税）
    @TableField(value = "service_date")
    private Date serviceDate; // 业务日期
    @TableField(value = "base_premium_tax_mny")
    private BigDecimal basePremiumTaxMny; // 初始保费金额(含税)
    @TableField(value = "guarantee_effect_date")
    private Date guaranteeEffectDate; // 担保生效期
    @TableField(value = "bid_person_name")
    private String bidPersonName; // 招标人

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getSelfCode() {
        return selfCode;
    }

    public void setSelfCode(String selfCode) {
        this.selfCode = selfCode;
    }

    public String getApplyArea() {
        return applyArea;
    }

    public void setApplyArea(String applyArea) {
        this.applyArea = applyArea;
    }

    public String getApplyAreaName() {
        return applyAreaName;
    }

    public void setApplyAreaName(String applyAreaName) {
        this.applyAreaName = applyAreaName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getApplicant() {
        return applicant;
    }

    public void setApplicant(Long applicant) {
        this.applicant = applicant;
    }

    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }

    public Long getProjectType() {
        return projectType;
    }

    public void setProjectType(Long projectType) {
        this.projectType = projectType;
    }

    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }

    public BigDecimal getBaseTaxMny() {
        return baseTaxMny;
    }

    public void setBaseTaxMny(BigDecimal baseTaxMny) {
        this.baseTaxMny = baseTaxMny;
    }

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public BigDecimal getBasePremiumTaxMny() {
        return basePremiumTaxMny;
    }

    public void setBasePremiumTaxMny(BigDecimal basePremiumTaxMny) {
        this.basePremiumTaxMny = basePremiumTaxMny;
    }

    public Date getGuaranteeEffectDate() {
        return guaranteeEffectDate;
    }

    public void setGuaranteeEffectDate(Date guaranteeEffectDate) {
        this.guaranteeEffectDate = guaranteeEffectDate;
    }

    public String getBidPersonName() {
        return bidPersonName;
    }

    public void setBidPersonName(String bidPersonName) {
        this.bidPersonName = bidPersonName;
    }
}

==> ejc-guarantee-impl-3.0.0-20240829.062504-72-sources.jar: com/ejianc/business/guarantee/contract/bean/ContractBidEntity.java <==
package com.ejianc.business.guarantee.contract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 投标担保
 *
 * @author generator
 */
@TableName("ejc_guarantee_contract_bid")
public class ContractBidEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; // 单据编码
    @TableField(value = "org_id")
    private Long orgId; // 组织id
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "create_user_name")
    private String createUserName; // 编制人
    @TableField(value = "operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value = "operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value = "update_user_name")
    private String updateUserName; // 修改者
    @TableField(value = "remark")
    private String remark; // 备注
    @TableField(value = "contract_id")
    private Long contractId; // 合同评审id
    @TableField(value = "contract_name")
    private String contractName; // 合同名称
    @TableField(value = "project_id")
    private String projectId; // 项目
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "self_code")
    private String selfCode; // 自定义编号
    @TableField(value = "apply_area")
    private String applyArea; // 申请地区
    @TableField(value = "apply_area_name")
    private String applyAreaName; // 申请地区名称
    @TableField(value = "employee_id")
    private Long employeeId; // 委托保证人
    @TableField(value = "employee_name")
    private String employeeName; // 委托保证人名称
    @TableField(value = "applicant")
    private Long applicant; // 申请人
    @TableField(value = "applicant_name")
    private String applicantName; // 申请名称
    @TableField(value = "project_type")
    private Long projectType; // 项目类型
    @TableField(value = "project_type_name")
    private String projectTypeName; // 项目类型名称
    @TableField(value = "base_tax_mny")
    private BigDecimal baseTaxMny; // 初始担保金额（含税）
    @TableField(value = "service_date")
    private Date serviceDate; // 业务日期
    @TableField(value = "base_premium_tax_mny")
    private BigDecimal basePremiumTaxMny; // 初始保费金额(含税)
    @TableField(value = "guarantee_effect_date")
    private Date guaranteeEffectDate; // 担保生效期
    @TableField(value = "bid_person_name")
    private String bidPersonName; // 招标人
    @TableField(value = "letter_date")
    private Date letterDate; //出函时间

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getSelfCode() {
        return selfCode;
    }

    public void setSelfCode(String selfCode) {
        this.selfCode = selfCode;
    }

    public String getApplyArea() {
        return applyArea;
    }

    public void setApplyArea(String applyArea) {
        this.applyArea = applyArea;
    }

    public String getApplyAreaName() {
        return applyAreaName;
    }

    public void setApplyAreaName(String applyAreaName) {
        this.applyAreaName = applyAreaName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getApplicant() {
        return applicant;
    }

    public void setApplicant(Long applicant) {
        this.applicant = applicant;
    }

    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }

    public Long getProjectType() {
        return projectType;
    }

    public void setProjectType(Long projectType) {
        this.projectType = projectType;
    }

    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }

    public BigDecimal getBaseTaxMny() {
        return baseTaxMny;
    }

    public void setBaseTaxMny(BigDecimal baseTaxMny) {
        this.baseTaxMny = baseTaxMny;
    }

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public BigDecimal getBasePremiumTaxMny() {
        return basePremiumTaxMny;
    }

    public void setBasePremiumTaxMny(BigDecimal basePremiumTaxMny) {
        this.basePremiumTaxMny = basePremiumTaxMny;
    }

    public Date getGuaranteeEffectDate() {
        return guaranteeEffectDate;
    }

    public void setGuaranteeEffectDate(Date guaranteeEffectDate) {
        this.guaranteeEffectDate = guaranteeEffectDate;
    }

    public String getBidPersonName() {
        return bidPersonName;
    }

    public void setBidPersonName(String bidPersonName) {
        this.bidPersonName = bidPersonName;
    }

    public Date getLetterDate() {
        return letterDate;
    }

    public void setLetterDate(Date letterDate) {
        this.letterDate = letterDate;
    }
}
